@@ -30,9 +30,10 @@ from calculate.lib.cl_ini_parser import iniParser
 from calculate.lib.cl_print import color_print
 from calculate.lib.utils.ip import Pinger, IPError
 from calculate.lib.utils.files import (getModeFile, removeDir,
-                                       isMount, pathJoin, tarLinks,
+                                       pathJoin, tarLinks,
                                        listDirectory, process, find, STDOUT,
                                        sambaPasswordCheck, checkUtils)
+from calculate.lib.utils.mount import isMount
 from calculate.lib.utils.common import cmpVersion
 from calculate.desktop._cl_keys import getKey, clearKey
 from calculate.lib.convertenv import convertEnv
@@ -1088,10 +1089,10 @@ class Client(commandServer, encrypt, Desktop):
         else:
             self.printERROR(_("Server %s does not respond") % domain)
             return False
-        reFoundHostSamba = re.compile("Server=\[Samba.+\]")
         smbClientCmd = checkUtils('/usr/bin/smbclient')
-        p = process(smbClientCmd, "-N", "-L", domain, stderr=STDOUT)
-        if p.success() and any(reFoundHostSamba.search(x) for x in p):
+        p = process(smbClientCmd, "-N", "//{}/remote".format(domain),
+                    stderr=STDOUT)
+        if "NT_STATUS_ACCESS_DENIED" p.read():
             return True
         else:
             self.printERROR(_("Samba server not found in %s") % domain)
